@@ -5,7 +5,7 @@ use mro 'c3';
 extends 'Catalyst::Model';
 with 'CatalystX::Component::Traits';
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 $VERSION = eval $VERSION;
 
 use namespace::autoclean;
@@ -24,107 +24,65 @@ Catalyst::Model::DBIC::Schema - DBIx::Class::Schema Model Class
 
 =head1 SYNOPSIS
 
-Manual creation of a DBIx::Class::Schema and a Catalyst::Model::DBIC::Schema:
+First, prepare your database schema using L<DBIx::Class>, see
+L<Catalyst::Helper::Model::DBIC::Schema> for how to generate a
+L<DBIx::Class::Schema> from your database using the Helper script, and
+L<DBIx::Class::Schema::Loader::Base>.
 
-=over
+A typical usage of the helper script would be:
 
-=item 1.
+    script/myapp_create.pl model FilmDB DBIC::Schema MyApp::Schema::FilmDB \
+        create=static dbi:mysql:filmdb dbusername dbpass \
+        quote_char='`' name_sep='.'
 
-Create the DBIx:Class schema in MyApp/Schema/FilmDB.pm:
+If you are unfamiliar with L<DBIx::Class>, see L<DBIx::Class::Manual::Intro>
+first.
 
-  package MyApp::Schema::FilmDB;
-  use base qw/DBIx::Class::Schema/;
+These examples assume that you already have a schema called
+C<MyApp::Schema::FilmDB>, which defines some Result classes for tables in
+C<MyApp::Schema::FilmDB::Result::Actor> and
+C<MyApp::Schema::FilmDB::Result::Film>. Either created by the helper script (as
+shown above) or manually.
 
-  __PACKAGE__->load_classes(qw/Actor Role/);
+The helper also creates a Model in C<lib/MyApp/Model/FilmDB.pm>, if you already
+have a schema you can create just the Model using:
 
-=item 2.
+    script/myapp_create.pl model FilmDB DBIC::Schema MyApp::Schema::FilmDB
+        dbi:mysql:filmdb dbusername dbpass
 
-Create some classes for the tables in the database, for example an 
-Actor in MyApp/Schema/FilmDB/Actor.pm:
-
-  package MyApp::Schema::FilmDB::Actor;
-  use base qw/DBIx::Class/
-
-  __PACKAGE__->load_components(qw/Core/);
-  __PACKAGE__->table('actor');
-
-  ...
-
-and a Role in MyApp/Schema/FilmDB/Role.pm:
-
-  package MyApp::Schema::FilmDB::Role;
-  use base qw/DBIx::Class/
-
-  __PACKAGE__->load_components(qw/Core/);
-  __PACKAGE__->table('role');
-
-  ...    
-
-Notice that the schema is in MyApp::Schema, not in MyApp::Model. This way it's 
-usable as a standalone module and you can test/run it without Catalyst. 
-
-=item 3.
-
-To expose it to Catalyst as a model, you should create a DBIC Model in
-MyApp/Model/FilmDB.pm:
-
-  package MyApp::Model::FilmDB;
-  use base qw/Catalyst::Model::DBIC::Schema/;
-
-  __PACKAGE__->config(
-      schema_class => 'MyApp::Schema::FilmDB',
-      connect_info => {
-                        dsn => "DBI:...",
-                        user => "username",
-                        password => "password",
-                      }
-  );
-
-See below for a full list of the possible config parameters.
-
-=back
+The connect_info is optional and will be hardcoded into the Model if provided.
+It's better to configure it in your L<Catalyst> config file, which will also
+override any hardcoded config, see L</connect_info> for examples.
 
 Now you have a working Model which accesses your separate DBIC Schema. This can
-be used/accessed in the normal Catalyst manner, via $c->model():
+be used/accessed in the normal Catalyst manner, via C<< $c->model() >>:
 
-  my $actor = $c->model('FilmDB::Actor')->find(1);
+  my $db_model = $c->model('FilmDB');         # a Catalyst::Model
+  my $dbic     = $c->model('FilmDB')->schema; # the actual DBIC object
 
-You can also use it to set up DBIC authentication with 
-L<Catalyst::Authentication::Store::DBIx::Class> in MyApp.pm:
+The Model proxies to the C<Schema> instance so you can do:
 
-  package MyApp;
+  my $rs = $db_model->resultset('Actor');     # ... or ...
+  my $rs = $dbic    ->resultset('Actor');     # same!
 
-  use Catalyst qw/... Authentication .../;
+There is also a shortcut, which returns a L<DBIx::Class::ResultSet> directly,
+instead of a L<Catalyst::Model>:
 
-  ...
+  my $rs = $c->model('FilmDB::Actor');
 
-  __PACKAGE__->config->{authentication} = 
-                {  
-                    default_realm => 'members',
-                    realms => {
-                        members => {
-                            credential => {
-                                class => 'Password',
-                                password_field => 'password',
-                                password_type => 'hashed'
-                                password_hash_type => 'SHA-256'
-                            },
-                            store => {
-                                class => 'DBIx::Class',
-                                user_model => 'DB::User',
-                                role_relation => 'roles',
-                                role_field => 'rolename',                   
-                            }
-                        }
-                    }
-                };
+See L<DBIx::Class::ResultSet> to find out more about which methods can be
+called on ResultSets.
 
-C<< $c->model('Schema::Source') >> returns a L<DBIx::Class::ResultSet> for 
-the source name parameter passed. To find out more about which methods can 
-be called on a ResultSet, or how to add your own methods to it, please see 
-the ResultSet documentation in the L<DBIx::Class> distribution.
+You can also define your own ResultSet methods to encapsulate the
+database/business logic of your applications. These go into, for example,
+C<lib/MyApp/Schema/FilmDB/ResultSet/Actor.pm>. The class must inherit from
+L<DBIx::Class::ResultSet> and is automatically loaded.
 
-Some examples are given below:
+Then call your methods like any other L<DBIx::Class::ResultSet> method:
+
+    $c->model('FilmDB::Actor')->SAG_members
+
+=head2 Some examples:
 
   # to access schema methods directly:
   $c->model('FilmDB')->schema->source(...);
@@ -154,17 +112,19 @@ Some examples are given below:
   $newconn->storage_type('::LDAP');
   $newconn->connection(...);
 
+To set up authentication, see L</"Setting up DBIC authentication"> below.
+
 =head1 DESCRIPTION
 
 This is a Catalyst Model for L<DBIx::Class::Schema>-based Models.  See
 the documentation for L<Catalyst::Helper::Model::DBIC::Schema> for
 information on generating these Models via Helper scripts.
 
-When your Catalyst app starts up, a thin Model layer is created as an 
-interface to your DBIC Schema. It should be clearly noted that the model 
-object returned by C<< $c->model('FilmDB') >> is NOT itself a DBIC schema or 
-resultset object, but merely a wrapper proving L<methods|/METHODS> to access 
-the underlying schema. 
+When your Catalyst app starts up, a thin Model layer is created as an interface
+to your DBIC Schema. It should be clearly noted that the model object returned
+by C<< $c->model('FilmDB') >> is NOT itself a DBIC schema or resultset object,
+but merely a wrapper proving L<methods|/METHODS> to access the underlying
+schema (but also proxies other methods to the underlying schema.) 
 
 In addition to this model class, a shortcut class is generated for each 
 source in the schema, allowing easy and direct access to a resultset of the 
@@ -194,8 +154,15 @@ resultset object:
 
 In order to add methods to a DBIC resultset, you cannot simply add them to 
 the source (row, table) definition class; you must define a separate custom 
-resultset class. See L<DBIx::Class::Manual::Cookbook/"Predefined searches"> 
-for more info.
+resultset class. This is just a matter of making a
+C<lib/MyApp/Schema/ResultSet/Actor.pm> class that inherits from
+L<DBIx::Class::ResultSet>, if you are using
+L<DBIx::Class::Schema/load_namespaces>, the default for helper script generated
+schemas.
+
+See L<DBIx::Class::Manual::Cookbook/"Predefined searches"> 
+for information on definining your own L<DBIx::Class::ResultSet> classes for
+use with L<DBIx::Class::Schema/load_classes>, the old default.
 
 =head1 CONFIG PARAMETERS
 
@@ -495,13 +462,15 @@ sub BUILD {
 
     $self->composed_schema($schema_class->compose_namespace($class));
 
+    my $was_mutable = $self->meta->is_mutable;
+
     $self->meta->make_mutable;
     $self->meta->add_attribute('schema',
         is => 'rw',
         isa => 'DBIx::Class::Schema',
         handles => $self->_delegates
     );
-    $self->meta->make_immutable;
+    $self->meta->make_immutable unless $was_mutable;
 
     $self->schema($self->composed_schema->clone);
 
@@ -653,11 +622,42 @@ __PACKAGE__->meta->make_immutable;
 
 =item CMDS_NO_SOURCES
 
-Set this variable if you will be using schemas with no sources (tables) to
-disable the warning. The warning is there because this is usually a mistake.
+Set this variable if you will be using schemas with no sources (Result classes)
+to disable the warning. The warning is there because having no Result classes
+is usually a mistake.
 
 =back
 
+=head1 Setting up DBIC authentication
+
+You can set this up with 
+L<Catalyst::Authentication::Store::DBIx::Class> in MyApp.pm:
+
+  package MyApp;
+
+  use Catalyst qw/... Authentication .../;
+
+  ...
+
+  __PACKAGE__->config('Plugin::Authentication' =>
+                {
+                    default_realm => 'members',
+                    members => {
+                        credential => {
+                            class => 'Password',
+                            password_field => 'password',
+                            password_type => 'hashed'
+                            password_hash_type => 'SHA-256'
+                        },
+                        store => {
+                            class => 'DBIx::Class',
+                            user_model => 'DB::User',
+                            role_relation => 'roles',
+                            role_field => 'rolename',
+                        }
+                    }
+                });
+
 =head1 SEE ALSO
 
 General Catalyst Stuff:
@@ -674,7 +674,8 @@ L<CatalystX::Component::Traits>, L<MooseX::Traits::Pluggable>
 Traits:
 
 L<Catalyst::TraitFor::Model::DBIC::Schema::Caching>,
-L<Catalyst::TraitFor::Model::DBIC::Schema::Replicated>
+L<Catalyst::TraitFor::Model::DBIC::Schema::Replicated>,
+L<Catalyst::TraitFor::Model::DBIC::Schema::QueryLog>
 
 =head1 AUTHOR
 
@@ -684,9 +685,15 @@ Brandon L Black C<blblack at gmail.com>
 
 caelum: Rafael Kitover C<rkitover at cpan.org>
 
-Dan Dascalescu C<dandv at cpan.org>
+dandv: Dan Dascalescu C<dandv at cpan.org>
 
-Aran Deltac C<bluefeet@cpan.org>
+bluefeet: Aran Deltac C<bluefeet@cpan.org>
+
+t0m: Tomas Doran C<bobtfish@bobtfish.net>
+
+osfameron: C<osfameron@cpan.org>
+
+ozum: Ozum Eldogan C<ozum@ozum.net>
 
 =head1 COPYRIGHT
 
